/* gitg-ref-action-tag-info.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-ref-action-tag-info.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2023 - Alberto Fanjul
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include "libgitg-ext.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "libgitg.h"
#include "config.h"
#include <gtk/gtk.h>
#include <libgit2-glib/ggit.h>
#include <glib/gi18n-lib.h>

#define GITG_REF_ACTION_TAG_SHOW_INFO_version VERSION
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_REF_ACTION_TAG_SHOW_INFO (gitg_ref_action_tag_show_info_get_type ())
#define GITG_REF_ACTION_TAG_SHOW_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_REF_ACTION_TAG_SHOW_INFO, GitgRefActionTagShowInfo))
#define GITG_REF_ACTION_TAG_SHOW_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_REF_ACTION_TAG_SHOW_INFO, GitgRefActionTagShowInfoClass))
#define GITG_IS_REF_ACTION_TAG_SHOW_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_REF_ACTION_TAG_SHOW_INFO))
#define GITG_IS_REF_ACTION_TAG_SHOW_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_REF_ACTION_TAG_SHOW_INFO))
#define GITG_REF_ACTION_TAG_SHOW_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_REF_ACTION_TAG_SHOW_INFO, GitgRefActionTagShowInfoClass))

typedef struct _GitgRefActionTagShowInfo GitgRefActionTagShowInfo;
typedef struct _GitgRefActionTagShowInfoClass GitgRefActionTagShowInfoClass;
typedef struct _GitgRefActionTagShowInfoPrivate GitgRefActionTagShowInfoPrivate;
enum  {
	GITG_REF_ACTION_TAG_SHOW_INFO_0_PROPERTY,
	GITG_REF_ACTION_TAG_SHOW_INFO_APPLICATION_PROPERTY,
	GITG_REF_ACTION_TAG_SHOW_INFO_ACTION_INTERFACE_PROPERTY,
	GITG_REF_ACTION_TAG_SHOW_INFO_REFERENCE_PROPERTY,
	GITG_REF_ACTION_TAG_SHOW_INFO_AVAILABLE_PROPERTY,
	GITG_REF_ACTION_TAG_SHOW_INFO_ID_PROPERTY,
	GITG_REF_ACTION_TAG_SHOW_INFO_DISPLAY_NAME_PROPERTY,
	GITG_REF_ACTION_TAG_SHOW_INFO_DESCRIPTION_PROPERTY,
	GITG_REF_ACTION_TAG_SHOW_INFO_NUM_PROPERTIES
};
static GParamSpec* gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GITG_TYPE_TAG_SHOW_INFO_DIALOG (gitg_tag_show_info_dialog_get_type ())
#define GITG_TAG_SHOW_INFO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_TAG_SHOW_INFO_DIALOG, GitgTagShowInfoDialog))
#define GITG_TAG_SHOW_INFO_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_TAG_SHOW_INFO_DIALOG, GitgTagShowInfoDialogClass))
#define GITG_IS_TAG_SHOW_INFO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_TAG_SHOW_INFO_DIALOG))
#define GITG_IS_TAG_SHOW_INFO_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_TAG_SHOW_INFO_DIALOG))
#define GITG_TAG_SHOW_INFO_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_TAG_SHOW_INFO_DIALOG, GitgTagShowInfoDialogClass))

typedef struct _GitgTagShowInfoDialog GitgTagShowInfoDialog;
typedef struct _GitgTagShowInfoDialogClass GitgTagShowInfoDialogClass;
typedef struct _Block84Data Block84Data;

struct _GitgRefActionTagShowInfo {
	GObject parent_instance;
	GitgRefActionTagShowInfoPrivate * priv;
};

struct _GitgRefActionTagShowInfoClass {
	GObjectClass parent_class;
	void (*activate) (GitgRefActionTagShowInfo* self);
	gchar* (*get_description) (GitgRefActionTagShowInfo* self);
};

struct _GitgRefActionTagShowInfoPrivate {
	GitgExtApplication* _application;
	GitgExtRefActionInterface* _action_interface;
	GitgRef* _reference;
};

struct _Block84Data {
	int _ref_count_;
	GitgRefActionTagShowInfo* self;
	GitgTagShowInfoDialog* dlg;
};

static gint GitgRefActionTagShowInfo_private_offset;
static gpointer gitg_ref_action_tag_show_info_parent_class = NULL;
static GitgExtUIElementIface * gitg_ref_action_tag_show_info_gitg_ext_ui_element_parent_iface = NULL;
static GitgExtActionIface * gitg_ref_action_tag_show_info_gitg_ext_action_parent_iface = NULL;
static GitgExtRefActionIface * gitg_ref_action_tag_show_info_gitg_ext_ref_action_parent_iface = NULL;

VALA_EXTERN GType gitg_ref_action_tag_show_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgRefActionTagShowInfo, g_object_unref)
VALA_EXTERN void gitg_ref_action_tag_show_info_activate (GitgRefActionTagShowInfo* self);
VALA_EXTERN gchar* gitg_ref_action_tag_show_info_get_description (GitgRefActionTagShowInfo* self);
static void gitg_ref_action_tag_show_info_real_activate (GitgRefActionTagShowInfo* self);
VALA_EXTERN GType gitg_tag_show_info_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgTagShowInfoDialog, g_object_unref)
static Block84Data* block84_data_ref (Block84Data* _data84_);
static void block84_data_unref (void * _userdata_);
VALA_EXTERN GitgTagShowInfoDialog* gitg_tag_show_info_dialog_new (GtkWindow* parent,
                                                      GitgRef* reference);
VALA_EXTERN GitgTagShowInfoDialog* gitg_tag_show_info_dialog_construct (GType object_type,
                                                            GtkWindow* parent,
                                                            GitgRef* reference);
static void __lambda225_ (Block84Data* _data84_,
                   GtkDialog* d,
                   gint resp);
static void ___lambda225__gtk_dialog_response (GtkDialog* _sender,
                                        gint response_id,
                                        gpointer self);
VALA_EXTERN GitgRefActionTagShowInfo* gitg_ref_action_tag_show_info_new (GitgExtApplication* application,
                                                             GitgExtRefActionInterface* action_interface,
                                                             GitgRef* reference);
VALA_EXTERN GitgRefActionTagShowInfo* gitg_ref_action_tag_show_info_construct (GType object_type,
                                                                   GitgExtApplication* application,
                                                                   GitgExtRefActionInterface* action_interface,
                                                                   GitgRef* reference);
static void gitg_ref_action_tag_show_info_finalize (GObject * obj);
static GType gitg_ref_action_tag_show_info_get_type_once (void);
static void _vala_gitg_ref_action_tag_show_info_get_property (GObject * object,
                                                       guint property_id,
                                                       GValue * value,
                                                       GParamSpec * pspec);
static void _vala_gitg_ref_action_tag_show_info_set_property (GObject * object,
                                                       guint property_id,
                                                       const GValue * value,
                                                       GParamSpec * pspec);

static inline gpointer
gitg_ref_action_tag_show_info_get_instance_private (GitgRefActionTagShowInfo* self)
{
	return G_STRUCT_MEMBER_P (self, GitgRefActionTagShowInfo_private_offset);
}

static Block84Data*
block84_data_ref (Block84Data* _data84_)
{
	g_atomic_int_inc (&_data84_->_ref_count_);
	return _data84_;
}

static void
block84_data_unref (void * _userdata_)
{
	Block84Data* _data84_;
	_data84_ = (Block84Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data84_->_ref_count_)) {
		GitgRefActionTagShowInfo* self;
		self = _data84_->self;
		_g_object_unref0 (_data84_->dlg);
		_g_object_unref0 (self);
		g_slice_free (Block84Data, _data84_);
	}
}

static void
__lambda225_ (Block84Data* _data84_,
              GtkDialog* d,
              gint resp)
{
	GitgRefActionTagShowInfo* self;
	self = _data84_->self;
	g_return_if_fail (d != NULL);
	gtk_widget_destroy ((GtkWidget*) _data84_->dlg);
	g_signal_emit_by_name ((GitgExtRefAction*) self, "finished");
}

static void
___lambda225__gtk_dialog_response (GtkDialog* _sender,
                                   gint response_id,
                                   gpointer self)
{
	__lambda225_ (self, _sender, response_id);
}

static void
gitg_ref_action_tag_show_info_real_activate (GitgRefActionTagShowInfo* self)
{
	Block84Data* _data84_;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	GtkWindow* _tmp2_;
	GitgRef* _tmp3_;
	GitgRef* _tmp4_;
	GitgTagShowInfoDialog* _tmp5_;
	GitgTagShowInfoDialog* _tmp6_;
	_data84_ = g_slice_new0 (Block84Data);
	_data84_->_ref_count_ = 1;
	_data84_->self = g_object_ref (self);
	_tmp0_ = gitg_ext_ui_element_get_application ((GitgExtUIElement*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow);
	_tmp3_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
	_tmp4_ = _tmp3_;
	_tmp5_ = gitg_tag_show_info_dialog_new (_tmp2_, _tmp4_);
	g_object_ref_sink (_tmp5_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp2_);
	_data84_->dlg = _tmp6_;
	g_signal_connect_data ((GtkDialog*) _data84_->dlg, "response", (GCallback) ___lambda225__gtk_dialog_response, block84_data_ref (_data84_), (GClosureNotify) block84_data_unref, 0);
	gtk_widget_show ((GtkWidget*) _data84_->dlg);
	block84_data_unref (_data84_);
	_data84_ = NULL;
}

void
gitg_ref_action_tag_show_info_activate (GitgRefActionTagShowInfo* self)
{
	GitgRefActionTagShowInfoClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GITG_REF_ACTION_TAG_SHOW_INFO_GET_CLASS (self);
	if (_klass_->activate) {
		_klass_->activate (self);
	}
}

GitgRefActionTagShowInfo*
gitg_ref_action_tag_show_info_construct (GType object_type,
                                         GitgExtApplication* application,
                                         GitgExtRefActionInterface* action_interface,
                                         GitgRef* reference)
{
	GitgRefActionTagShowInfo * self = NULL;
	g_return_val_if_fail (application != NULL, NULL);
	g_return_val_if_fail (action_interface != NULL, NULL);
	g_return_val_if_fail (reference != NULL, NULL);
	self = (GitgRefActionTagShowInfo*) g_object_new (object_type, "application", application, "action-interface", action_interface, "reference", reference, NULL);
	return self;
}

GitgRefActionTagShowInfo*
gitg_ref_action_tag_show_info_new (GitgExtApplication* application,
                                   GitgExtRefActionInterface* action_interface,
                                   GitgRef* reference)
{
	return gitg_ref_action_tag_show_info_construct (GITG_TYPE_REF_ACTION_TAG_SHOW_INFO, application, action_interface, reference);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static GitgExtApplication*
gitg_ref_action_tag_show_info_real_get_application (GitgExtUIElement* base)
{
	GitgExtApplication* result;
	GitgRefActionTagShowInfo* self;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	self = (GitgRefActionTagShowInfo*) base;
	_tmp0_ = self->priv->_application;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}

static void
gitg_ref_action_tag_show_info_real_set_application (GitgExtUIElement* base,
                                                    GitgExtApplication* value)
{
	GitgRefActionTagShowInfo* self;
	GitgExtApplication* old_value;
	self = (GitgRefActionTagShowInfo*) base;
	old_value = gitg_ref_action_tag_show_info_real_get_application (base);
	if (old_value != value) {
		GitgExtApplication* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_application);
		self->priv->_application = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_APPLICATION_PROPERTY]);
	}
	_g_object_unref0 (old_value);
}

static GitgExtRefActionInterface*
gitg_ref_action_tag_show_info_real_get_action_interface (GitgExtRefAction* base)
{
	GitgExtRefActionInterface* result;
	GitgRefActionTagShowInfo* self;
	GitgExtRefActionInterface* _tmp0_;
	self = (GitgRefActionTagShowInfo*) base;
	_tmp0_ = self->priv->_action_interface;
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_tag_show_info_real_set_action_interface (GitgExtRefAction* base,
                                                         GitgExtRefActionInterface* value)
{
	GitgRefActionTagShowInfo* self;
	GitgExtRefActionInterface* old_value;
	self = (GitgRefActionTagShowInfo*) base;
	old_value = gitg_ref_action_tag_show_info_real_get_action_interface (base);
	if (old_value != value) {
		GitgExtRefActionInterface* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_action_interface);
		self->priv->_action_interface = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_ACTION_INTERFACE_PROPERTY]);
	}
}

static GitgRef*
gitg_ref_action_tag_show_info_real_get_reference (GitgExtRefAction* base)
{
	GitgRef* result;
	GitgRefActionTagShowInfo* self;
	GitgRef* _tmp0_;
	self = (GitgRefActionTagShowInfo*) base;
	_tmp0_ = self->priv->_reference;
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_tag_show_info_real_set_reference (GitgExtRefAction* base,
                                                  GitgRef* value)
{
	GitgRefActionTagShowInfo* self;
	GitgRef* old_value;
	self = (GitgRefActionTagShowInfo*) base;
	old_value = gitg_ref_action_tag_show_info_real_get_reference (base);
	if (old_value != value) {
		GitgRef* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_reference);
		self->priv->_reference = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_REFERENCE_PROPERTY]);
	}
}

static gboolean
gitg_ref_action_tag_show_info_real_get_available (GitgExtUIElement* base)
{
	gboolean result;
	GitgRefActionTagShowInfo* self;
	GitgRef* _tmp0_;
	GitgRef* _tmp1_;
	self = (GitgRefActionTagShowInfo*) base;
	_tmp0_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
	_tmp1_ = _tmp0_;
	result = ggit_ref_is_tag ((GgitRef*) _tmp1_);
	return result;
}

static gchar*
gitg_ref_action_tag_show_info_real_get_id (GitgExtUIElement* base)
{
	gchar* result;
	GitgRefActionTagShowInfo* self;
	gchar* _tmp0_;
	self = (GitgRefActionTagShowInfo*) base;
	_tmp0_ = g_strdup ("/org/gnome/gitg/ref-actions/tag-show-info");
	result = _tmp0_;
	return result;
}

static gchar*
gitg_ref_action_tag_show_info_real_get_display_name (GitgExtUIElement* base)
{
	gchar* result;
	GitgRefActionTagShowInfo* self;
	gchar* _tmp0_;
	self = (GitgRefActionTagShowInfo*) base;
	_tmp0_ = g_strdup (_ ("Show tag info"));
	result = _tmp0_;
	return result;
}

gchar*
gitg_ref_action_tag_show_info_get_description (GitgRefActionTagShowInfo* self)
{
	GitgRefActionTagShowInfoClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GITG_REF_ACTION_TAG_SHOW_INFO_GET_CLASS (self);
	if (_klass_->get_description) {
		return _klass_->get_description (self);
	}
	return NULL;
}

static gchar*
gitg_ref_action_tag_show_info_real_get_description (GitgRefActionTagShowInfo* base)
{
	gchar* result;
	GitgRefActionTagShowInfo* self;
	gchar* _tmp0_;
	self = base;
	_tmp0_ = g_strdup (_ ("Show info at selected tag"));
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_tag_show_info_class_init (GitgRefActionTagShowInfoClass * klass,
                                          gpointer klass_data)
{
	gitg_ref_action_tag_show_info_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgRefActionTagShowInfo_private_offset);
	((GitgRefActionTagShowInfoClass *) klass)->activate = (void (*) (GitgRefActionTagShowInfo*)) gitg_ref_action_tag_show_info_real_activate;
	GITG_REF_ACTION_TAG_SHOW_INFO_CLASS (klass)->get_description = (gchar* (*) (GitgRefActionTagShowInfo*)) gitg_ref_action_tag_show_info_real_get_description;
	G_OBJECT_CLASS (klass)->get_property = _vala_gitg_ref_action_tag_show_info_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gitg_ref_action_tag_show_info_set_property;
	G_OBJECT_CLASS (klass)->finalize = gitg_ref_action_tag_show_info_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_TAG_SHOW_INFO_APPLICATION_PROPERTY, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_APPLICATION_PROPERTY] = g_param_spec_object ("application", "application", "application", GITG_EXT_TYPE_APPLICATION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_TAG_SHOW_INFO_ACTION_INTERFACE_PROPERTY, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_ACTION_INTERFACE_PROPERTY] = g_param_spec_object ("action-interface", "action-interface", "action-interface", GITG_EXT_TYPE_REF_ACTION_INTERFACE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_TAG_SHOW_INFO_REFERENCE_PROPERTY, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_REFERENCE_PROPERTY] = g_param_spec_object ("reference", "reference", "reference", GITG_TYPE_REF, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_TAG_SHOW_INFO_AVAILABLE_PROPERTY, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_AVAILABLE_PROPERTY] = g_param_spec_boolean ("available", "available", "available", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_TAG_SHOW_INFO_ID_PROPERTY, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_TAG_SHOW_INFO_DISPLAY_NAME_PROPERTY, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_DISPLAY_NAME_PROPERTY] = g_param_spec_string ("display-name", "display-name", "display-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_TAG_SHOW_INFO_DESCRIPTION_PROPERTY, gitg_ref_action_tag_show_info_properties[GITG_REF_ACTION_TAG_SHOW_INFO_DESCRIPTION_PROPERTY] = g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gitg_ref_action_tag_show_info_gitg_ext_ui_element_interface_init (GitgExtUIElementIface * iface,
                                                                  gpointer iface_data)
{
	gitg_ref_action_tag_show_info_gitg_ext_ui_element_parent_iface = g_type_interface_peek_parent (iface);
	iface->activate = (void (*) (GitgExtUIElement*)) gitg_ref_action_tag_show_info_activate;
	iface->get_application = gitg_ref_action_tag_show_info_real_get_application;
	iface->set_application = gitg_ref_action_tag_show_info_real_set_application;
	iface->get_available = gitg_ref_action_tag_show_info_real_get_available;
	iface->get_id = gitg_ref_action_tag_show_info_real_get_id;
	iface->get_display_name = gitg_ref_action_tag_show_info_real_get_display_name;
	iface->get_description = (gchar* (*) (GitgExtUIElement*)) gitg_ref_action_tag_show_info_get_description;
}

static void
gitg_ref_action_tag_show_info_gitg_ext_action_interface_init (GitgExtActionIface * iface,
                                                              gpointer iface_data)
{
	gitg_ref_action_tag_show_info_gitg_ext_action_parent_iface = g_type_interface_peek_parent (iface);
}

static void
gitg_ref_action_tag_show_info_gitg_ext_ref_action_interface_init (GitgExtRefActionIface * iface,
                                                                  gpointer iface_data)
{
	gitg_ref_action_tag_show_info_gitg_ext_ref_action_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_action_interface = gitg_ref_action_tag_show_info_real_get_action_interface;
	iface->set_action_interface = gitg_ref_action_tag_show_info_real_set_action_interface;
	iface->get_reference = gitg_ref_action_tag_show_info_real_get_reference;
	iface->set_reference = gitg_ref_action_tag_show_info_real_set_reference;
}

static void
gitg_ref_action_tag_show_info_instance_init (GitgRefActionTagShowInfo * self,
                                             gpointer klass)
{
	self->priv = gitg_ref_action_tag_show_info_get_instance_private (self);
}

static void
gitg_ref_action_tag_show_info_finalize (GObject * obj)
{
	GitgRefActionTagShowInfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_REF_ACTION_TAG_SHOW_INFO, GitgRefActionTagShowInfo);
	_g_object_unref0 (self->priv->_application);
	_g_object_unref0 (self->priv->_action_interface);
	_g_object_unref0 (self->priv->_reference);
	G_OBJECT_CLASS (gitg_ref_action_tag_show_info_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_ref_action_tag_show_info_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgRefActionTagShowInfoClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_ref_action_tag_show_info_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgRefActionTagShowInfo), 0, (GInstanceInitFunc) gitg_ref_action_tag_show_info_instance_init, NULL };
	static const GInterfaceInfo gitg_ext_ui_element_info = { (GInterfaceInitFunc) gitg_ref_action_tag_show_info_gitg_ext_ui_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_ext_action_info = { (GInterfaceInitFunc) gitg_ref_action_tag_show_info_gitg_ext_action_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_ext_ref_action_info = { (GInterfaceInitFunc) gitg_ref_action_tag_show_info_gitg_ext_ref_action_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_ref_action_tag_show_info_type_id;
	gitg_ref_action_tag_show_info_type_id = g_type_register_static (G_TYPE_OBJECT, "GitgRefActionTagShowInfo", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_ref_action_tag_show_info_type_id, GITG_EXT_TYPE_UI_ELEMENT, &gitg_ext_ui_element_info);
	g_type_add_interface_static (gitg_ref_action_tag_show_info_type_id, GITG_EXT_TYPE_ACTION, &gitg_ext_action_info);
	g_type_add_interface_static (gitg_ref_action_tag_show_info_type_id, GITG_EXT_TYPE_REF_ACTION, &gitg_ext_ref_action_info);
	GitgRefActionTagShowInfo_private_offset = g_type_add_instance_private (gitg_ref_action_tag_show_info_type_id, sizeof (GitgRefActionTagShowInfoPrivate));
	return gitg_ref_action_tag_show_info_type_id;
}

GType
gitg_ref_action_tag_show_info_get_type (void)
{
	static gsize gitg_ref_action_tag_show_info_type_id__once = 0;
	if (g_once_init_enter (&gitg_ref_action_tag_show_info_type_id__once)) {
		GType gitg_ref_action_tag_show_info_type_id;
		gitg_ref_action_tag_show_info_type_id = gitg_ref_action_tag_show_info_get_type_once ();
		g_once_init_leave (&gitg_ref_action_tag_show_info_type_id__once, gitg_ref_action_tag_show_info_type_id);
	}
	return gitg_ref_action_tag_show_info_type_id__once;
}

static void
_vala_gitg_ref_action_tag_show_info_get_property (GObject * object,
                                                  guint property_id,
                                                  GValue * value,
                                                  GParamSpec * pspec)
{
	GitgRefActionTagShowInfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_REF_ACTION_TAG_SHOW_INFO, GitgRefActionTagShowInfo);
	switch (property_id) {
		case GITG_REF_ACTION_TAG_SHOW_INFO_APPLICATION_PROPERTY:
		g_value_take_object (value, gitg_ext_ui_element_get_application ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_TAG_SHOW_INFO_ACTION_INTERFACE_PROPERTY:
		g_value_set_object (value, gitg_ext_ref_action_get_action_interface ((GitgExtRefAction*) self));
		break;
		case GITG_REF_ACTION_TAG_SHOW_INFO_REFERENCE_PROPERTY:
		g_value_set_object (value, gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self));
		break;
		case GITG_REF_ACTION_TAG_SHOW_INFO_AVAILABLE_PROPERTY:
		g_value_set_boolean (value, gitg_ext_ui_element_get_available ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_TAG_SHOW_INFO_ID_PROPERTY:
		g_value_take_string (value, gitg_ext_ui_element_get_id ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_TAG_SHOW_INFO_DISPLAY_NAME_PROPERTY:
		g_value_take_string (value, gitg_ext_ui_element_get_display_name ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_TAG_SHOW_INFO_DESCRIPTION_PROPERTY:
		g_value_take_string (value, gitg_ref_action_tag_show_info_get_description (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gitg_ref_action_tag_show_info_set_property (GObject * object,
                                                  guint property_id,
                                                  const GValue * value,
                                                  GParamSpec * pspec)
{
	GitgRefActionTagShowInfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_REF_ACTION_TAG_SHOW_INFO, GitgRefActionTagShowInfo);
	switch (property_id) {
		case GITG_REF_ACTION_TAG_SHOW_INFO_APPLICATION_PROPERTY:
		gitg_ext_ui_element_set_application ((GitgExtUIElement*) self, g_value_get_object (value));
		break;
		case GITG_REF_ACTION_TAG_SHOW_INFO_ACTION_INTERFACE_PROPERTY:
		gitg_ext_ref_action_set_action_interface ((GitgExtRefAction*) self, g_value_get_object (value));
		break;
		case GITG_REF_ACTION_TAG_SHOW_INFO_REFERENCE_PROPERTY:
		gitg_ext_ref_action_set_reference ((GitgExtRefAction*) self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

