/* gitg-ref-action-set-upstream-branch.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-ref-action-set-upstream-branch.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2025 - Alberto Fanjul
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include "libgitg-ext.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "libgitg.h"
#include "config.h"
#include <gtk/gtk.h>
#include <libgit2-glib/ggit.h>
#include <glib/gi18n-lib.h>

#define GITG_REF_ACTION_SET_UPSTREAM_BRANCH_version VERSION
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH (gitg_ref_action_set_upstream_branch_get_type ())
#define GITG_REF_ACTION_SET_UPSTREAM_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH, GitgRefActionSetUpstreamBranch))
#define GITG_REF_ACTION_SET_UPSTREAM_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH, GitgRefActionSetUpstreamBranchClass))
#define GITG_IS_REF_ACTION_SET_UPSTREAM_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH))
#define GITG_IS_REF_ACTION_SET_UPSTREAM_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH))
#define GITG_REF_ACTION_SET_UPSTREAM_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH, GitgRefActionSetUpstreamBranchClass))

typedef struct _GitgRefActionSetUpstreamBranch GitgRefActionSetUpstreamBranch;
typedef struct _GitgRefActionSetUpstreamBranchClass GitgRefActionSetUpstreamBranchClass;
typedef struct _GitgRefActionSetUpstreamBranchPrivate GitgRefActionSetUpstreamBranchPrivate;
enum  {
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_0_PROPERTY,
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_APPLICATION_PROPERTY,
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ACTION_INTERFACE_PROPERTY,
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_REFERENCE_PROPERTY,
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ENABLED_PROPERTY,
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ID_PROPERTY,
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_DESCRIPTION_PROPERTY,
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_DISPLAY_NAME_PROPERTY,
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_NUM_PROPERTIES
};
static GParamSpec* gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GITG_TYPE_SET_UPSTREAM_BRANCH_DIALOG (gitg_set_upstream_branch_dialog_get_type ())
#define GITG_SET_UPSTREAM_BRANCH_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_SET_UPSTREAM_BRANCH_DIALOG, GitgSetUpstreamBranchDialog))
#define GITG_SET_UPSTREAM_BRANCH_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_SET_UPSTREAM_BRANCH_DIALOG, GitgSetUpstreamBranchDialogClass))
#define GITG_IS_SET_UPSTREAM_BRANCH_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_SET_UPSTREAM_BRANCH_DIALOG))
#define GITG_IS_SET_UPSTREAM_BRANCH_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_SET_UPSTREAM_BRANCH_DIALOG))
#define GITG_SET_UPSTREAM_BRANCH_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_SET_UPSTREAM_BRANCH_DIALOG, GitgSetUpstreamBranchDialogClass))

typedef struct _GitgSetUpstreamBranchDialog GitgSetUpstreamBranchDialog;
typedef struct _GitgSetUpstreamBranchDialogClass GitgSetUpstreamBranchDialogClass;
typedef struct _Block85Data Block85Data;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

struct _GitgRefActionSetUpstreamBranch {
	GObject parent_instance;
	GitgRefActionSetUpstreamBranchPrivate * priv;
};

struct _GitgRefActionSetUpstreamBranchClass {
	GObjectClass parent_class;
	void (*activate) (GitgRefActionSetUpstreamBranch* self);
	gchar* (*get_description) (GitgRefActionSetUpstreamBranch* self);
};

struct _GitgRefActionSetUpstreamBranchPrivate {
	GitgExtApplication* _application;
	GitgExtRefActionInterface* _action_interface;
	GitgRef* _reference;
};

struct _Block85Data {
	int _ref_count_;
	GitgRefActionSetUpstreamBranch* self;
	GitgSetUpstreamBranchDialog* dlg;
};

static gint GitgRefActionSetUpstreamBranch_private_offset;
static gpointer gitg_ref_action_set_upstream_branch_parent_class = NULL;
static GitgExtUIElementIface * gitg_ref_action_set_upstream_branch_gitg_ext_ui_element_parent_iface = NULL;
static GitgExtActionIface * gitg_ref_action_set_upstream_branch_gitg_ext_action_parent_iface = NULL;
static GitgExtRefActionIface * gitg_ref_action_set_upstream_branch_gitg_ext_ref_action_parent_iface = NULL;

VALA_EXTERN GType gitg_ref_action_set_upstream_branch_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgRefActionSetUpstreamBranch, g_object_unref)
VALA_EXTERN void gitg_ref_action_set_upstream_branch_activate (GitgRefActionSetUpstreamBranch* self);
VALA_EXTERN gchar* gitg_ref_action_set_upstream_branch_get_description (GitgRefActionSetUpstreamBranch* self);
VALA_EXTERN GitgRefActionSetUpstreamBranch* gitg_ref_action_set_upstream_branch_new (GitgExtApplication* application,
                                                                         GitgExtRefActionInterface* action_interface,
                                                                         GitgRef* reference);
VALA_EXTERN GitgRefActionSetUpstreamBranch* gitg_ref_action_set_upstream_branch_construct (GType object_type,
                                                                               GitgExtApplication* application,
                                                                               GitgExtRefActionInterface* action_interface,
                                                                               GitgRef* reference);
static void gitg_ref_action_set_upstream_branch_real_activate (GitgRefActionSetUpstreamBranch* self);
VALA_EXTERN GType gitg_set_upstream_branch_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgSetUpstreamBranchDialog, g_object_unref)
static Block85Data* block85_data_ref (Block85Data* _data85_);
static void block85_data_unref (void * _userdata_);
VALA_EXTERN GitgSetUpstreamBranchDialog* gitg_set_upstream_branch_dialog_new (GtkWindow* parent,
                                                                  GitgRepository* repository,
                                                                  GitgRef* reference);
VALA_EXTERN GitgSetUpstreamBranchDialog* gitg_set_upstream_branch_dialog_construct (GType object_type,
                                                                        GtkWindow* parent,
                                                                        GitgRepository* repository,
                                                                        GitgRef* reference);
static void __lambda213_ (Block85Data* _data85_,
                   GtkDialog* d,
                   gint resp);
VALA_EXTERN gchar* gitg_set_upstream_branch_dialog_get_remote_branch_name (GitgSetUpstreamBranchDialog* self);
static void ___lambda213__gtk_dialog_response (GtkDialog* _sender,
                                        gint response_id,
                                        gpointer self);
static void gitg_ref_action_set_upstream_branch_finalize (GObject * obj);
static GType gitg_ref_action_set_upstream_branch_get_type_once (void);
static void _vala_gitg_ref_action_set_upstream_branch_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec);
static void _vala_gitg_ref_action_set_upstream_branch_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec);

static inline gpointer
gitg_ref_action_set_upstream_branch_get_instance_private (GitgRefActionSetUpstreamBranch* self)
{
	return G_STRUCT_MEMBER_P (self, GitgRefActionSetUpstreamBranch_private_offset);
}

GitgRefActionSetUpstreamBranch*
gitg_ref_action_set_upstream_branch_construct (GType object_type,
                                               GitgExtApplication* application,
                                               GitgExtRefActionInterface* action_interface,
                                               GitgRef* reference)
{
	GitgRefActionSetUpstreamBranch * self = NULL;
	g_return_val_if_fail (application != NULL, NULL);
	g_return_val_if_fail (action_interface != NULL, NULL);
	g_return_val_if_fail (reference != NULL, NULL);
	self = (GitgRefActionSetUpstreamBranch*) g_object_new (object_type, "application", application, "action-interface", action_interface, "reference", reference, NULL);
	return self;
}

GitgRefActionSetUpstreamBranch*
gitg_ref_action_set_upstream_branch_new (GitgExtApplication* application,
                                         GitgExtRefActionInterface* action_interface,
                                         GitgRef* reference)
{
	return gitg_ref_action_set_upstream_branch_construct (GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH, application, action_interface, reference);
}

static Block85Data*
block85_data_ref (Block85Data* _data85_)
{
	g_atomic_int_inc (&_data85_->_ref_count_);
	return _data85_;
}

static void
block85_data_unref (void * _userdata_)
{
	Block85Data* _data85_;
	_data85_ = (Block85Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data85_->_ref_count_)) {
		GitgRefActionSetUpstreamBranch* self;
		self = _data85_->self;
		_g_object_unref0 (_data85_->dlg);
		_g_object_unref0 (self);
		g_slice_free (Block85Data, _data85_);
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
__lambda213_ (Block85Data* _data85_,
              GtkDialog* d,
              gint resp)
{
	GitgRefActionSetUpstreamBranch* self;
	GError* _inner_error0_ = NULL;
	self = _data85_->self;
	g_return_if_fail (d != NULL);
	if (resp == ((gint) GTK_RESPONSE_OK)) {
		GitgBranch* branch = NULL;
		branch = NULL;
		{
			GitgRef* _tmp0_;
			GitgRef* _tmp1_;
			GitgBranch* _tmp2_;
			gchar* upstream = NULL;
			gchar* _tmp3_;
			gchar* _tmp4_;
			const gchar* _tmp5_;
			GitgBranch* _tmp6_;
			const gchar* _tmp7_;
			_tmp0_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
			_tmp1_ = _tmp0_;
			_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GITG_TYPE_BRANCH) ? ((GitgBranch*) _tmp1_) : NULL);
			_g_object_unref0 (branch);
			branch = _tmp2_;
			_tmp3_ = gitg_set_upstream_branch_dialog_get_remote_branch_name (_data85_->dlg);
			_tmp4_ = _tmp3_;
			upstream = _tmp4_;
			_tmp5_ = upstream;
			if (g_strcmp0 (_tmp5_, "") == 0) {
				_g_free0 (upstream);
				upstream = NULL;
			}
			_tmp6_ = branch;
			_tmp7_ = upstream;
			ggit_branch_set_upstream ((GgitBranch*) _tmp6_, _tmp7_, &_inner_error0_);
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				_g_free0 (upstream);
				goto __catch0_g_error;
			}
			_g_free0 (upstream);
		}
		goto __finally0;
		__catch0_g_error:
		{
			GError* e = NULL;
			GitgExtApplication* _tmp8_;
			GitgExtApplication* _tmp9_;
			GitgExtApplication* _tmp10_;
			GError* _tmp11_;
			const gchar* _tmp12_;
			e = _inner_error0_;
			_inner_error0_ = NULL;
			_tmp8_ = gitg_ext_ui_element_get_application ((GitgExtUIElement*) self);
			_tmp9_ = _tmp8_;
			_tmp10_ = _tmp9_;
			_tmp11_ = e;
			_tmp12_ = _tmp11_->message;
			gitg_ext_application_show_infobar (_tmp10_, _ ("Failed to set upstream to branch"), _tmp12_, GTK_MESSAGE_ERROR);
			_g_object_unref0 (_tmp10_);
			_g_error_free0 (e);
		}
		__finally0:
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_object_unref0 (branch);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return;
		}
		_g_object_unref0 (branch);
	}
	gtk_widget_destroy ((GtkWidget*) _data85_->dlg);
	g_signal_emit_by_name ((GitgExtRefAction*) self, "finished");
}

static void
___lambda213__gtk_dialog_response (GtkDialog* _sender,
                                   gint response_id,
                                   gpointer self)
{
	__lambda213_ (self, _sender, response_id);
}

static void
gitg_ref_action_set_upstream_branch_real_activate (GitgRefActionSetUpstreamBranch* self)
{
	Block85Data* _data85_;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	GtkWindow* _tmp2_;
	GitgExtApplication* _tmp3_;
	GitgExtApplication* _tmp4_;
	GitgExtApplication* _tmp5_;
	GitgRepository* _tmp6_;
	GitgRepository* _tmp7_;
	GitgRepository* _tmp8_;
	GitgRef* _tmp9_;
	GitgRef* _tmp10_;
	GitgSetUpstreamBranchDialog* _tmp11_;
	GitgSetUpstreamBranchDialog* _tmp12_;
	_data85_ = g_slice_new0 (Block85Data);
	_data85_->_ref_count_ = 1;
	_data85_->self = g_object_ref (self);
	_tmp0_ = gitg_ext_ui_element_get_application ((GitgExtUIElement*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow);
	_tmp3_ = gitg_ext_ui_element_get_application ((GitgExtUIElement*) self);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_tmp6_ = gitg_ext_application_get_repository (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
	_tmp10_ = _tmp9_;
	_tmp11_ = gitg_set_upstream_branch_dialog_new (_tmp2_, _tmp8_, _tmp10_);
	g_object_ref_sink (_tmp11_);
	_tmp12_ = _tmp11_;
	_g_object_unref0 (_tmp8_);
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp2_);
	_data85_->dlg = _tmp12_;
	g_signal_connect_data ((GtkDialog*) _data85_->dlg, "response", (GCallback) ___lambda213__gtk_dialog_response, block85_data_ref (_data85_), (GClosureNotify) block85_data_unref, 0);
	gtk_widget_show ((GtkWidget*) _data85_->dlg);
	block85_data_unref (_data85_);
	_data85_ = NULL;
}

void
gitg_ref_action_set_upstream_branch_activate (GitgRefActionSetUpstreamBranch* self)
{
	GitgRefActionSetUpstreamBranchClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = GITG_REF_ACTION_SET_UPSTREAM_BRANCH_GET_CLASS (self);
	if (_klass_->activate) {
		_klass_->activate (self);
	}
}

static GitgExtApplication*
gitg_ref_action_set_upstream_branch_real_get_application (GitgExtUIElement* base)
{
	GitgExtApplication* result;
	GitgRefActionSetUpstreamBranch* self;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	self = (GitgRefActionSetUpstreamBranch*) base;
	_tmp0_ = self->priv->_application;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}

static void
gitg_ref_action_set_upstream_branch_real_set_application (GitgExtUIElement* base,
                                                          GitgExtApplication* value)
{
	GitgRefActionSetUpstreamBranch* self;
	GitgExtApplication* old_value;
	self = (GitgRefActionSetUpstreamBranch*) base;
	old_value = gitg_ref_action_set_upstream_branch_real_get_application (base);
	if (old_value != value) {
		GitgExtApplication* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_application);
		self->priv->_application = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_APPLICATION_PROPERTY]);
	}
	_g_object_unref0 (old_value);
}

static GitgExtRefActionInterface*
gitg_ref_action_set_upstream_branch_real_get_action_interface (GitgExtRefAction* base)
{
	GitgExtRefActionInterface* result;
	GitgRefActionSetUpstreamBranch* self;
	GitgExtRefActionInterface* _tmp0_;
	self = (GitgRefActionSetUpstreamBranch*) base;
	_tmp0_ = self->priv->_action_interface;
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_set_upstream_branch_real_set_action_interface (GitgExtRefAction* base,
                                                               GitgExtRefActionInterface* value)
{
	GitgRefActionSetUpstreamBranch* self;
	GitgExtRefActionInterface* old_value;
	self = (GitgRefActionSetUpstreamBranch*) base;
	old_value = gitg_ref_action_set_upstream_branch_real_get_action_interface (base);
	if (old_value != value) {
		GitgExtRefActionInterface* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_action_interface);
		self->priv->_action_interface = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ACTION_INTERFACE_PROPERTY]);
	}
}

static GitgRef*
gitg_ref_action_set_upstream_branch_real_get_reference (GitgExtRefAction* base)
{
	GitgRef* result;
	GitgRefActionSetUpstreamBranch* self;
	GitgRef* _tmp0_;
	self = (GitgRefActionSetUpstreamBranch*) base;
	_tmp0_ = self->priv->_reference;
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_set_upstream_branch_real_set_reference (GitgExtRefAction* base,
                                                        GitgRef* value)
{
	GitgRefActionSetUpstreamBranch* self;
	GitgRef* old_value;
	self = (GitgRefActionSetUpstreamBranch*) base;
	old_value = gitg_ref_action_set_upstream_branch_real_get_reference (base);
	if (old_value != value) {
		GitgRef* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_reference);
		self->priv->_reference = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_REFERENCE_PROPERTY]);
	}
}

static gboolean
gitg_ref_action_set_upstream_branch_real_get_enabled (GitgExtUIElement* base)
{
	gboolean result;
	GitgRefActionSetUpstreamBranch* self;
	gboolean _tmp5_ = FALSE;
	GError* _inner_error0_ = NULL;
	self = (GitgRefActionSetUpstreamBranch*) base;
	{
		gboolean _tmp0_ = FALSE;
		GitgRef* _tmp1_;
		GitgRef* _tmp2_;
		_tmp1_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
		_tmp2_ = _tmp1_;
		if (ggit_ref_is_branch ((GgitRef*) _tmp2_)) {
			GitgRef* _tmp3_;
			GitgRef* _tmp4_;
			_tmp3_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
			_tmp4_ = _tmp3_;
			_tmp0_ = !ggit_ref_is_remote ((GgitRef*) _tmp4_);
		} else {
			_tmp0_ = FALSE;
		}
		result = _tmp0_;
		return result;
	}
	goto __finally0;
	__catch0_g_error:
	{
		g_clear_error (&_inner_error0_);
	}
	__finally0:
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
	g_clear_error (&_inner_error0_);
	return _tmp5_;
	result = FALSE;
	return result;
}

static gchar*
gitg_ref_action_set_upstream_branch_real_get_id (GitgExtUIElement* base)
{
	gchar* result;
	GitgRefActionSetUpstreamBranch* self;
	gchar* _tmp0_;
	self = (GitgRefActionSetUpstreamBranch*) base;
	_tmp0_ = g_strdup ("/org/gnome/gitg/ref-actions/set-upstream-branch");
	result = _tmp0_;
	return result;
}

gchar*
gitg_ref_action_set_upstream_branch_get_description (GitgRefActionSetUpstreamBranch* self)
{
	GitgRefActionSetUpstreamBranchClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GITG_REF_ACTION_SET_UPSTREAM_BRANCH_GET_CLASS (self);
	if (_klass_->get_description) {
		return _klass_->get_description (self);
	}
	return NULL;
}

static gchar*
gitg_ref_action_set_upstream_branch_real_get_description (GitgRefActionSetUpstreamBranch* base)
{
	gchar* result;
	GitgRefActionSetUpstreamBranch* self;
	gchar* _tmp0_;
	self = base;
	_tmp0_ = g_strdup (_ ("Set Upstream repo for branch selected"));
	result = _tmp0_;
	return result;
}

static gchar*
gitg_ref_action_set_upstream_branch_real_get_display_name (GitgExtUIElement* base)
{
	gchar* result;
	GitgRefActionSetUpstreamBranch* self;
	gchar* _tmp0_;
	self = (GitgRefActionSetUpstreamBranch*) base;
	_tmp0_ = g_strdup (_ ("Set Upstream branch…"));
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_set_upstream_branch_class_init (GitgRefActionSetUpstreamBranchClass * klass,
                                                gpointer klass_data)
{
	gitg_ref_action_set_upstream_branch_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgRefActionSetUpstreamBranch_private_offset);
	((GitgRefActionSetUpstreamBranchClass *) klass)->activate = (void (*) (GitgRefActionSetUpstreamBranch*)) gitg_ref_action_set_upstream_branch_real_activate;
	GITG_REF_ACTION_SET_UPSTREAM_BRANCH_CLASS (klass)->get_description = (gchar* (*) (GitgRefActionSetUpstreamBranch*)) gitg_ref_action_set_upstream_branch_real_get_description;
	G_OBJECT_CLASS (klass)->get_property = _vala_gitg_ref_action_set_upstream_branch_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gitg_ref_action_set_upstream_branch_set_property;
	G_OBJECT_CLASS (klass)->finalize = gitg_ref_action_set_upstream_branch_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_SET_UPSTREAM_BRANCH_APPLICATION_PROPERTY, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_APPLICATION_PROPERTY] = g_param_spec_object ("application", "application", "application", GITG_EXT_TYPE_APPLICATION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ACTION_INTERFACE_PROPERTY, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ACTION_INTERFACE_PROPERTY] = g_param_spec_object ("action-interface", "action-interface", "action-interface", GITG_EXT_TYPE_REF_ACTION_INTERFACE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_SET_UPSTREAM_BRANCH_REFERENCE_PROPERTY, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_REFERENCE_PROPERTY] = g_param_spec_object ("reference", "reference", "reference", GITG_TYPE_REF, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ENABLED_PROPERTY, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ENABLED_PROPERTY] = g_param_spec_boolean ("enabled", "enabled", "enabled", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ID_PROPERTY, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_SET_UPSTREAM_BRANCH_DESCRIPTION_PROPERTY, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_DESCRIPTION_PROPERTY] = g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_SET_UPSTREAM_BRANCH_DISPLAY_NAME_PROPERTY, gitg_ref_action_set_upstream_branch_properties[GITG_REF_ACTION_SET_UPSTREAM_BRANCH_DISPLAY_NAME_PROPERTY] = g_param_spec_string ("display-name", "display-name", "display-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gitg_ref_action_set_upstream_branch_gitg_ext_ui_element_interface_init (GitgExtUIElementIface * iface,
                                                                        gpointer iface_data)
{
	gitg_ref_action_set_upstream_branch_gitg_ext_ui_element_parent_iface = g_type_interface_peek_parent (iface);
	iface->activate = (void (*) (GitgExtUIElement*)) gitg_ref_action_set_upstream_branch_activate;
	iface->get_application = gitg_ref_action_set_upstream_branch_real_get_application;
	iface->set_application = gitg_ref_action_set_upstream_branch_real_set_application;
	iface->get_enabled = gitg_ref_action_set_upstream_branch_real_get_enabled;
	iface->get_id = gitg_ref_action_set_upstream_branch_real_get_id;
	iface->get_description = (gchar* (*) (GitgExtUIElement*)) gitg_ref_action_set_upstream_branch_get_description;
	iface->get_display_name = gitg_ref_action_set_upstream_branch_real_get_display_name;
}

static void
gitg_ref_action_set_upstream_branch_gitg_ext_action_interface_init (GitgExtActionIface * iface,
                                                                    gpointer iface_data)
{
	gitg_ref_action_set_upstream_branch_gitg_ext_action_parent_iface = g_type_interface_peek_parent (iface);
}

static void
gitg_ref_action_set_upstream_branch_gitg_ext_ref_action_interface_init (GitgExtRefActionIface * iface,
                                                                        gpointer iface_data)
{
	gitg_ref_action_set_upstream_branch_gitg_ext_ref_action_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_action_interface = gitg_ref_action_set_upstream_branch_real_get_action_interface;
	iface->set_action_interface = gitg_ref_action_set_upstream_branch_real_set_action_interface;
	iface->get_reference = gitg_ref_action_set_upstream_branch_real_get_reference;
	iface->set_reference = gitg_ref_action_set_upstream_branch_real_set_reference;
}

static void
gitg_ref_action_set_upstream_branch_instance_init (GitgRefActionSetUpstreamBranch * self,
                                                   gpointer klass)
{
	self->priv = gitg_ref_action_set_upstream_branch_get_instance_private (self);
}

static void
gitg_ref_action_set_upstream_branch_finalize (GObject * obj)
{
	GitgRefActionSetUpstreamBranch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH, GitgRefActionSetUpstreamBranch);
	_g_object_unref0 (self->priv->_application);
	_g_object_unref0 (self->priv->_action_interface);
	_g_object_unref0 (self->priv->_reference);
	G_OBJECT_CLASS (gitg_ref_action_set_upstream_branch_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_ref_action_set_upstream_branch_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgRefActionSetUpstreamBranchClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_ref_action_set_upstream_branch_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgRefActionSetUpstreamBranch), 0, (GInstanceInitFunc) gitg_ref_action_set_upstream_branch_instance_init, NULL };
	static const GInterfaceInfo gitg_ext_ui_element_info = { (GInterfaceInitFunc) gitg_ref_action_set_upstream_branch_gitg_ext_ui_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_ext_action_info = { (GInterfaceInitFunc) gitg_ref_action_set_upstream_branch_gitg_ext_action_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_ext_ref_action_info = { (GInterfaceInitFunc) gitg_ref_action_set_upstream_branch_gitg_ext_ref_action_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_ref_action_set_upstream_branch_type_id;
	gitg_ref_action_set_upstream_branch_type_id = g_type_register_static (G_TYPE_OBJECT, "GitgRefActionSetUpstreamBranch", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_ref_action_set_upstream_branch_type_id, GITG_EXT_TYPE_UI_ELEMENT, &gitg_ext_ui_element_info);
	g_type_add_interface_static (gitg_ref_action_set_upstream_branch_type_id, GITG_EXT_TYPE_ACTION, &gitg_ext_action_info);
	g_type_add_interface_static (gitg_ref_action_set_upstream_branch_type_id, GITG_EXT_TYPE_REF_ACTION, &gitg_ext_ref_action_info);
	GitgRefActionSetUpstreamBranch_private_offset = g_type_add_instance_private (gitg_ref_action_set_upstream_branch_type_id, sizeof (GitgRefActionSetUpstreamBranchPrivate));
	return gitg_ref_action_set_upstream_branch_type_id;
}

GType
gitg_ref_action_set_upstream_branch_get_type (void)
{
	static gsize gitg_ref_action_set_upstream_branch_type_id__once = 0;
	if (g_once_init_enter (&gitg_ref_action_set_upstream_branch_type_id__once)) {
		GType gitg_ref_action_set_upstream_branch_type_id;
		gitg_ref_action_set_upstream_branch_type_id = gitg_ref_action_set_upstream_branch_get_type_once ();
		g_once_init_leave (&gitg_ref_action_set_upstream_branch_type_id__once, gitg_ref_action_set_upstream_branch_type_id);
	}
	return gitg_ref_action_set_upstream_branch_type_id__once;
}

static void
_vala_gitg_ref_action_set_upstream_branch_get_property (GObject * object,
                                                        guint property_id,
                                                        GValue * value,
                                                        GParamSpec * pspec)
{
	GitgRefActionSetUpstreamBranch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH, GitgRefActionSetUpstreamBranch);
	switch (property_id) {
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_APPLICATION_PROPERTY:
		g_value_take_object (value, gitg_ext_ui_element_get_application ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ACTION_INTERFACE_PROPERTY:
		g_value_set_object (value, gitg_ext_ref_action_get_action_interface ((GitgExtRefAction*) self));
		break;
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_REFERENCE_PROPERTY:
		g_value_set_object (value, gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self));
		break;
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ENABLED_PROPERTY:
		g_value_set_boolean (value, gitg_ext_ui_element_get_enabled ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ID_PROPERTY:
		g_value_take_string (value, gitg_ext_ui_element_get_id ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_DESCRIPTION_PROPERTY:
		g_value_take_string (value, gitg_ref_action_set_upstream_branch_get_description (self));
		break;
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_DISPLAY_NAME_PROPERTY:
		g_value_take_string (value, gitg_ext_ui_element_get_display_name ((GitgExtUIElement*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gitg_ref_action_set_upstream_branch_set_property (GObject * object,
                                                        guint property_id,
                                                        const GValue * value,
                                                        GParamSpec * pspec)
{
	GitgRefActionSetUpstreamBranch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_REF_ACTION_SET_UPSTREAM_BRANCH, GitgRefActionSetUpstreamBranch);
	switch (property_id) {
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_APPLICATION_PROPERTY:
		gitg_ext_ui_element_set_application ((GitgExtUIElement*) self, g_value_get_object (value));
		break;
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_ACTION_INTERFACE_PROPERTY:
		gitg_ext_ref_action_set_action_interface ((GitgExtRefAction*) self, g_value_get_object (value));
		break;
		case GITG_REF_ACTION_SET_UPSTREAM_BRANCH_REFERENCE_PROPERTY:
		gitg_ext_ref_action_set_reference ((GitgExtRefAction*) self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

