/* gitg-commit-action-checkout.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-commit-action-checkout.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2014 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include "libgitg-ext.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "libgitg.h"
#include "config.h"
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <libgit2-glib/ggit.h>

#define GITG_COMMIT_ACTION_CHECKOUT_version VERSION
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_COMMIT_ACTION_CHECKOUT (gitg_commit_action_checkout_get_type ())
#define GITG_COMMIT_ACTION_CHECKOUT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_COMMIT_ACTION_CHECKOUT, GitgCommitActionCheckout))
#define GITG_COMMIT_ACTION_CHECKOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_COMMIT_ACTION_CHECKOUT, GitgCommitActionCheckoutClass))
#define GITG_IS_COMMIT_ACTION_CHECKOUT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_COMMIT_ACTION_CHECKOUT))
#define GITG_IS_COMMIT_ACTION_CHECKOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_COMMIT_ACTION_CHECKOUT))
#define GITG_COMMIT_ACTION_CHECKOUT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_COMMIT_ACTION_CHECKOUT, GitgCommitActionCheckoutClass))

typedef struct _GitgCommitActionCheckout GitgCommitActionCheckout;
typedef struct _GitgCommitActionCheckoutClass GitgCommitActionCheckoutClass;
typedef struct _GitgCommitActionCheckoutPrivate GitgCommitActionCheckoutPrivate;
enum  {
	GITG_COMMIT_ACTION_CHECKOUT_0_PROPERTY,
	GITG_COMMIT_ACTION_CHECKOUT_APPLICATION_PROPERTY,
	GITG_COMMIT_ACTION_CHECKOUT_ACTION_INTERFACE_PROPERTY,
	GITG_COMMIT_ACTION_CHECKOUT_COMMIT_PROPERTY,
	GITG_COMMIT_ACTION_CHECKOUT_ID_PROPERTY,
	GITG_COMMIT_ACTION_CHECKOUT_DISPLAY_NAME_PROPERTY,
	GITG_COMMIT_ACTION_CHECKOUT_DESCRIPTION_PROPERTY,
	GITG_COMMIT_ACTION_CHECKOUT_NUM_PROPERTIES
};
static GParamSpec* gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GITG_TYPE_SIMPLE_NOTIFICATION (gitg_simple_notification_get_type ())
#define GITG_SIMPLE_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_SIMPLE_NOTIFICATION, GitgSimpleNotification))
#define GITG_SIMPLE_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_SIMPLE_NOTIFICATION, GitgSimpleNotificationClass))
#define GITG_IS_SIMPLE_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_SIMPLE_NOTIFICATION))
#define GITG_IS_SIMPLE_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_SIMPLE_NOTIFICATION))
#define GITG_SIMPLE_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_SIMPLE_NOTIFICATION, GitgSimpleNotificationClass))

typedef struct _GitgSimpleNotification GitgSimpleNotification;
typedef struct _GitgSimpleNotificationClass GitgSimpleNotificationClass;
typedef struct _Block63Data Block63Data;
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GgitOId_free0(var) ((var == NULL) ? NULL : (var = (_vala_GgitOId_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _GitgCommitActionCheckoutCheckoutData GitgCommitActionCheckoutCheckoutData;

struct _GitgCommitActionCheckout {
	GObject parent_instance;
	GitgCommitActionCheckoutPrivate * priv;
};

struct _GitgCommitActionCheckoutClass {
	GObjectClass parent_class;
	gchar* (*get_id) (GitgCommitActionCheckout* self);
	gchar* (*get_description) (GitgCommitActionCheckout* self);
};

struct _GitgCommitActionCheckoutPrivate {
	GitgExtApplication* _application;
	GitgExtRefActionInterface* _action_interface;
	GitgCommit* _commit;
};

struct _Block63Data {
	int _ref_count_;
	GitgCommitActionCheckout* self;
	GitgRepository* repo;
	GitgSimpleNotification* notification;
	gboolean retval;
	gpointer _async_data_;
};

struct _GitgCommitActionCheckoutCheckoutData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GitgCommitActionCheckout* self;
	gboolean result;
	Block63Data* _data63_;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	GitgExtApplication* _tmp2_;
	GitgRepository* _tmp3_;
	GitgRepository* _tmp4_;
	GitgRepository* _tmp5_;
	GitgCommit* _tmp6_;
	GitgCommit* _tmp7_;
	GgitOId* _tmp8_;
	GgitOId* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	GitgSimpleNotification* _tmp14_;
	GitgSimpleNotification* _tmp15_;
	GitgExtApplication* _tmp16_;
	GitgExtApplication* _tmp17_;
	GitgExtApplication* _tmp18_;
	GitgExtNotifications* _tmp19_;
	GitgExtNotifications* _tmp20_;
	GitgExtNotifications* _tmp21_;
	GitgExtApplication* _tmp22_;
	GitgExtApplication* _tmp23_;
	GitgExtApplication* _tmp24_;
	GError* _inner_error0_;
};

static gint GitgCommitActionCheckout_private_offset;
static gpointer gitg_commit_action_checkout_parent_class = NULL;
static GitgExtUIElementIface * gitg_commit_action_checkout_gitg_ext_ui_element_parent_iface = NULL;
static GitgExtActionIface * gitg_commit_action_checkout_gitg_ext_action_parent_iface = NULL;
static GitgExtCommitActionIface * gitg_commit_action_checkout_gitg_ext_commit_action_parent_iface = NULL;

VALA_EXTERN GType gitg_commit_action_checkout_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgCommitActionCheckout, g_object_unref)
VALA_EXTERN gchar* gitg_commit_action_checkout_get_id (GitgCommitActionCheckout* self);
VALA_EXTERN gchar* gitg_commit_action_checkout_get_description (GitgCommitActionCheckout* self);
VALA_EXTERN GitgCommitActionCheckout* gitg_commit_action_checkout_new (GitgExtApplication* application,
                                                           GitgExtRefActionInterface* action_interface,
                                                           GitgCommit* commit);
VALA_EXTERN GitgCommitActionCheckout* gitg_commit_action_checkout_construct (GType object_type,
                                                                 GitgExtApplication* application,
                                                                 GitgExtRefActionInterface* action_interface,
                                                                 GitgCommit* commit);
static void gitg_commit_action_checkout_real_activate (GitgExtUIElement* base);
VALA_EXTERN void gitg_commit_action_checkout_checkout (GitgCommitActionCheckout* self,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN gboolean gitg_commit_action_checkout_checkout_finish (GitgCommitActionCheckout* self,
                                                      GAsyncResult* _res_);
static void gitg_commit_action_checkout_checkout_data_free (gpointer _data);
static gboolean gitg_commit_action_checkout_checkout_co (GitgCommitActionCheckoutCheckoutData* _data_);
VALA_EXTERN GType gitg_simple_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgSimpleNotification, g_object_unref)
static Block63Data* block63_data_ref (Block63Data* _data63_);
static void block63_data_unref (void * _userdata_);
VALA_EXTERN GitgSimpleNotification* gitg_simple_notification_new (const gchar* title,
                                                      const gchar* message);
VALA_EXTERN GitgSimpleNotification* gitg_simple_notification_construct (GType object_type,
                                                            const gchar* title,
                                                            const gchar* message);
static void _vala_GgitOId_free (GgitOId* self);
static void ___lambda233_ (Block63Data* _data63_,
                    GError** error);
VALA_EXTERN void gitg_simple_notification_error (GitgSimpleNotification* self,
                                     const gchar* message);
static void ____lambda233__gitg_async_thread_func (gpointer self,
                                            GError** error);
static void gitg_commit_action_checkout_checkout_ready (GObject* source_object,
                                                 GAsyncResult* _res_,
                                                 gpointer _user_data_);
VALA_EXTERN void gitg_simple_notification_success (GitgSimpleNotification* self,
                                       const gchar* message);
static void gitg_commit_action_checkout_finalize (GObject * obj);
static GType gitg_commit_action_checkout_get_type_once (void);
static void _vala_gitg_commit_action_checkout_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec);
static void _vala_gitg_commit_action_checkout_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec);

static inline gpointer
gitg_commit_action_checkout_get_instance_private (GitgCommitActionCheckout* self)
{
	return G_STRUCT_MEMBER_P (self, GitgCommitActionCheckout_private_offset);
}

GitgCommitActionCheckout*
gitg_commit_action_checkout_construct (GType object_type,
                                       GitgExtApplication* application,
                                       GitgExtRefActionInterface* action_interface,
                                       GitgCommit* commit)
{
	GitgCommitActionCheckout * self = NULL;
	g_return_val_if_fail (application != NULL, NULL);
	g_return_val_if_fail (action_interface != NULL, NULL);
	g_return_val_if_fail (commit != NULL, NULL);
	self = (GitgCommitActionCheckout*) g_object_new (object_type, "application", application, "action-interface", action_interface, "commit", commit, NULL);
	return self;
}

GitgCommitActionCheckout*
gitg_commit_action_checkout_new (GitgExtApplication* application,
                                 GitgExtRefActionInterface* action_interface,
                                 GitgCommit* commit)
{
	return gitg_commit_action_checkout_construct (GITG_TYPE_COMMIT_ACTION_CHECKOUT, application, action_interface, commit);
}

static void
gitg_commit_action_checkout_real_activate (GitgExtUIElement* base)
{
	GitgCommitActionCheckout * self;
	self = (GitgCommitActionCheckout*) base;
	gitg_commit_action_checkout_checkout (self, NULL, NULL);
}

static void
gitg_commit_action_checkout_checkout_data_free (gpointer _data)
{
	GitgCommitActionCheckoutCheckoutData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (GitgCommitActionCheckoutCheckoutData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
gitg_commit_action_checkout_checkout (GitgCommitActionCheckout* self,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_)
{
	GitgCommitActionCheckoutCheckoutData* _data_;
	GitgCommitActionCheckout* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (GitgCommitActionCheckoutCheckoutData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, gitg_commit_action_checkout_checkout_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	gitg_commit_action_checkout_checkout_co (_data_);
}

gboolean
gitg_commit_action_checkout_checkout_finish (GitgCommitActionCheckout* self,
                                             GAsyncResult* _res_)
{
	gboolean result;
	GitgCommitActionCheckoutCheckoutData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
	result = _data_->result;
	return result;
}

static Block63Data*
block63_data_ref (Block63Data* _data63_)
{
	g_atomic_int_inc (&_data63_->_ref_count_);
	return _data63_;
}

static void
block63_data_unref (void * _userdata_)
{
	Block63Data* _data63_;
	_data63_ = (Block63Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data63_->_ref_count_)) {
		GitgCommitActionCheckout* self;
		self = _data63_->self;
		_g_object_unref0 (_data63_->notification);
		_g_object_unref0 (_data63_->repo);
		_g_object_unref0 (self);
		g_slice_free (Block63Data, _data63_);
	}
}

static void
_vala_GgitOId_free (GgitOId* self)
{
	g_boxed_free (ggit_oid_get_type (), self);
}

static void
___lambda233_ (Block63Data* _data63_,
               GError** error)
{
	GitgCommitActionCheckout* self;
	GError* _inner_error0_ = NULL;
	self = _data63_->self;
	{
		GgitCheckoutOptions* opts = NULL;
		GgitCheckoutOptions* _tmp0_;
		GgitCheckoutOptions* _tmp1_;
		GitgCommit* _tmp2_;
		GitgCommit* _tmp3_;
		GgitTree* _tmp4_;
		GgitTree* _tmp5_;
		GgitCheckoutOptions* _tmp6_;
		_tmp0_ = ggit_checkout_options_new ();
		opts = _tmp0_;
		_tmp1_ = opts;
		ggit_checkout_options_set_strategy (_tmp1_, GGIT_CHECKOUT_SAFE);
		_tmp2_ = gitg_ext_commit_action_get_commit ((GitgExtCommitAction*) self);
		_tmp3_ = _tmp2_;
		_tmp4_ = ggit_commit_get_tree ((GgitCommit*) _tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = opts;
		ggit_repository_checkout_tree ((GgitRepository*) _data63_->repo, (GgitObject*) _tmp5_, _tmp6_, &_inner_error0_);
		_g_object_unref0 (_tmp5_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_object_unref0 (opts);
			goto __catch0_g_error;
		}
		_g_object_unref0 (opts);
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp7_ = e;
		_tmp8_ = _tmp7_->message;
		_tmp9_ = g_strdup_printf (_ ("Failed to checkout commit: %s"), _tmp8_);
		_tmp10_ = _tmp9_;
		gitg_simple_notification_error (_data63_->notification, _tmp10_);
		_g_free0 (_tmp10_);
		_g_error_free0 (e);
		return;
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return;
	}
	{
		GitgCommit* _tmp11_;
		GitgCommit* _tmp12_;
		GgitOId* _tmp13_;
		GgitOId* _tmp14_;
		_tmp11_ = gitg_ext_commit_action_get_commit ((GitgExtCommitAction*) self);
		_tmp12_ = _tmp11_;
		_tmp13_ = ggit_object_get_id ((GgitObject*) _tmp12_);
		_tmp14_ = _tmp13_;
		ggit_repository_set_head_detached ((GgitRepository*) _data63_->repo, _tmp14_, &_inner_error0_);
		__vala_GgitOId_free0 (_tmp14_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
		GError* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp15_ = e;
		_tmp16_ = _tmp15_->message;
		_tmp17_ = g_strdup_printf (_ ("Failed to update HEAD: %s"), _tmp16_);
		_tmp18_ = _tmp17_;
		gitg_simple_notification_error (_data63_->notification, _tmp18_);
		_g_free0 (_tmp18_);
		_g_error_free0 (e);
		return;
	}
	__finally1:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return;
	}
	_data63_->retval = TRUE;
}

static void
____lambda233__gitg_async_thread_func (gpointer self,
                                       GError** error)
{
	___lambda233_ (self, error);
}

static void
gitg_commit_action_checkout_checkout_ready (GObject* source_object,
                                            GAsyncResult* _res_,
                                            gpointer _user_data_)
{
	GitgCommitActionCheckoutCheckoutData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	gitg_commit_action_checkout_checkout_co (_data_);
}

static gboolean
gitg_commit_action_checkout_checkout_co (GitgCommitActionCheckoutCheckoutData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data63_ = g_slice_new0 (Block63Data);
	_data_->_data63_->_ref_count_ = 1;
	_data_->_data63_->self = g_object_ref (_data_->self);
	_data_->_data63_->_async_data_ = _data_;
	_data_->_tmp0_ = gitg_ext_ui_element_get_application ((GitgExtUIElement*) _data_->self);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = gitg_ext_application_get_repository (_data_->_tmp2_);
	_data_->_tmp4_ = _data_->_tmp3_;
	_data_->_tmp5_ = _data_->_tmp4_;
	_g_object_unref0 (_data_->_tmp2_);
	_data_->_data63_->repo = _data_->_tmp5_;
	_data_->_tmp6_ = gitg_ext_commit_action_get_commit ((GitgExtCommitAction*) _data_->self);
	_data_->_tmp7_ = _data_->_tmp6_;
	_data_->_tmp8_ = ggit_object_get_id ((GgitObject*) _data_->_tmp7_);
	_data_->_tmp9_ = _data_->_tmp8_;
	_data_->_tmp10_ = ggit_oid_to_string (_data_->_tmp9_);
	_data_->_tmp11_ = _data_->_tmp10_;
	_data_->_tmp12_ = g_strdup_printf (_ ("Checkout “%s”"), _data_->_tmp11_);
	_data_->_tmp13_ = _data_->_tmp12_;
	_data_->_tmp14_ = gitg_simple_notification_new (_data_->_tmp13_, NULL);
	g_object_ref_sink (_data_->_tmp14_);
	_data_->_tmp15_ = _data_->_tmp14_;
	_g_free0 (_data_->_tmp13_);
	_g_free0 (_data_->_tmp11_);
	__vala_GgitOId_free0 (_data_->_tmp9_);
	_data_->_data63_->notification = _data_->_tmp15_;
	_data_->_data63_->retval = FALSE;
	_data_->_tmp16_ = gitg_ext_ui_element_get_application ((GitgExtUIElement*) _data_->self);
	_data_->_tmp17_ = _data_->_tmp16_;
	_data_->_tmp18_ = _data_->_tmp17_;
	_data_->_tmp19_ = gitg_ext_application_get_notifications (_data_->_tmp18_);
	_data_->_tmp20_ = _data_->_tmp19_;
	_data_->_tmp21_ = _data_->_tmp20_;
	gitg_ext_notifications_add (_data_->_tmp21_, (GitgExtNotification*) _data_->_data63_->notification);
	_g_object_unref0 (_data_->_tmp21_);
	_g_object_unref0 (_data_->_tmp18_);
	{
		_data_->_state_ = 1;
		gitg_async_thread (____lambda233__gitg_async_thread_func, _data_->_data63_, gitg_commit_action_checkout_checkout_ready, _data_);
		return FALSE;
		_state_1:
		gitg_async_thread_finish (_data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		g_clear_error (&_data_->_inner_error0_);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		block63_data_unref (_data_->_data63_);
		_data_->_data63_ = NULL;
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	if (_data_->_data63_->retval) {
		gitg_simple_notification_success (_data_->_data63_->notification, _ ("Successfully checked out commit to working directory"));
		_data_->_tmp22_ = gitg_ext_ui_element_get_application ((GitgExtUIElement*) _data_->self);
		_data_->_tmp23_ = _data_->_tmp22_;
		_data_->_tmp24_ = _data_->_tmp23_;
		g_signal_emit_by_name (_data_->_tmp24_, "repository-commits-changed");
		_g_object_unref0 (_data_->_tmp24_);
	}
	_data_->result = _data_->_data63_->retval;
	block63_data_unref (_data_->_data63_);
	_data_->_data63_ = NULL;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static GitgExtApplication*
gitg_commit_action_checkout_real_get_application (GitgExtUIElement* base)
{
	GitgExtApplication* result;
	GitgCommitActionCheckout* self;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	self = (GitgCommitActionCheckout*) base;
	_tmp0_ = self->priv->_application;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}

static void
gitg_commit_action_checkout_real_set_application (GitgExtUIElement* base,
                                                  GitgExtApplication* value)
{
	GitgCommitActionCheckout* self;
	GitgExtApplication* old_value;
	self = (GitgCommitActionCheckout*) base;
	old_value = gitg_commit_action_checkout_real_get_application (base);
	if (old_value != value) {
		GitgExtApplication* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_application);
		self->priv->_application = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_APPLICATION_PROPERTY]);
	}
	_g_object_unref0 (old_value);
}

static GitgExtRefActionInterface*
gitg_commit_action_checkout_real_get_action_interface (GitgExtCommitAction* base)
{
	GitgExtRefActionInterface* result;
	GitgCommitActionCheckout* self;
	GitgExtRefActionInterface* _tmp0_;
	self = (GitgCommitActionCheckout*) base;
	_tmp0_ = self->priv->_action_interface;
	result = _tmp0_;
	return result;
}

static void
gitg_commit_action_checkout_real_set_action_interface (GitgExtCommitAction* base,
                                                       GitgExtRefActionInterface* value)
{
	GitgCommitActionCheckout* self;
	GitgExtRefActionInterface* old_value;
	self = (GitgCommitActionCheckout*) base;
	old_value = gitg_commit_action_checkout_real_get_action_interface (base);
	if (old_value != value) {
		GitgExtRefActionInterface* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_action_interface);
		self->priv->_action_interface = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_ACTION_INTERFACE_PROPERTY]);
	}
}

static GitgCommit*
gitg_commit_action_checkout_real_get_commit (GitgExtCommitAction* base)
{
	GitgCommit* result;
	GitgCommitActionCheckout* self;
	GitgCommit* _tmp0_;
	self = (GitgCommitActionCheckout*) base;
	_tmp0_ = self->priv->_commit;
	result = _tmp0_;
	return result;
}

static void
gitg_commit_action_checkout_real_set_commit (GitgExtCommitAction* base,
                                             GitgCommit* value)
{
	GitgCommitActionCheckout* self;
	GitgCommit* old_value;
	self = (GitgCommitActionCheckout*) base;
	old_value = gitg_commit_action_checkout_real_get_commit (base);
	if (old_value != value) {
		GitgCommit* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_commit);
		self->priv->_commit = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_COMMIT_PROPERTY]);
	}
}

gchar*
gitg_commit_action_checkout_get_id (GitgCommitActionCheckout* self)
{
	GitgCommitActionCheckoutClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GITG_COMMIT_ACTION_CHECKOUT_GET_CLASS (self);
	if (_klass_->get_id) {
		return _klass_->get_id (self);
	}
	return NULL;
}

static gchar*
gitg_commit_action_checkout_real_get_id (GitgCommitActionCheckout* base)
{
	gchar* result;
	GitgCommitActionCheckout* self;
	gchar* _tmp0_;
	self = base;
	_tmp0_ = g_strdup ("/org/gnome/gitg/commit-actions/checkout");
	result = _tmp0_;
	return result;
}

static gchar*
gitg_commit_action_checkout_real_get_display_name (GitgExtUIElement* base)
{
	gchar* result;
	GitgCommitActionCheckout* self;
	gchar* _tmp0_;
	self = (GitgCommitActionCheckout*) base;
	_tmp0_ = g_strdup (_ ("Checkout detached"));
	result = _tmp0_;
	return result;
}

gchar*
gitg_commit_action_checkout_get_description (GitgCommitActionCheckout* self)
{
	GitgCommitActionCheckoutClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = GITG_COMMIT_ACTION_CHECKOUT_GET_CLASS (self);
	if (_klass_->get_description) {
		return _klass_->get_description (self);
	}
	return NULL;
}

static gchar*
gitg_commit_action_checkout_real_get_description (GitgCommitActionCheckout* base)
{
	gchar* result;
	GitgCommitActionCheckout* self;
	gchar* _tmp0_;
	self = base;
	_tmp0_ = g_strdup (_ ("Checkout at selected commit"));
	result = _tmp0_;
	return result;
}

static void
gitg_commit_action_checkout_class_init (GitgCommitActionCheckoutClass * klass,
                                        gpointer klass_data)
{
	gitg_commit_action_checkout_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgCommitActionCheckout_private_offset);
	GITG_COMMIT_ACTION_CHECKOUT_CLASS (klass)->get_id = (gchar* (*) (GitgCommitActionCheckout*)) gitg_commit_action_checkout_real_get_id;
	GITG_COMMIT_ACTION_CHECKOUT_CLASS (klass)->get_description = (gchar* (*) (GitgCommitActionCheckout*)) gitg_commit_action_checkout_real_get_description;
	G_OBJECT_CLASS (klass)->get_property = _vala_gitg_commit_action_checkout_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gitg_commit_action_checkout_set_property;
	G_OBJECT_CLASS (klass)->finalize = gitg_commit_action_checkout_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_ACTION_CHECKOUT_APPLICATION_PROPERTY, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_APPLICATION_PROPERTY] = g_param_spec_object ("application", "application", "application", GITG_EXT_TYPE_APPLICATION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_ACTION_CHECKOUT_ACTION_INTERFACE_PROPERTY, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_ACTION_INTERFACE_PROPERTY] = g_param_spec_object ("action-interface", "action-interface", "action-interface", GITG_EXT_TYPE_REF_ACTION_INTERFACE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_ACTION_CHECKOUT_COMMIT_PROPERTY, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_COMMIT_PROPERTY] = g_param_spec_object ("commit", "commit", "commit", GITG_TYPE_COMMIT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_ACTION_CHECKOUT_ID_PROPERTY, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_ACTION_CHECKOUT_DISPLAY_NAME_PROPERTY, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_DISPLAY_NAME_PROPERTY] = g_param_spec_string ("display-name", "display-name", "display-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_ACTION_CHECKOUT_DESCRIPTION_PROPERTY, gitg_commit_action_checkout_properties[GITG_COMMIT_ACTION_CHECKOUT_DESCRIPTION_PROPERTY] = g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gitg_commit_action_checkout_gitg_ext_ui_element_interface_init (GitgExtUIElementIface * iface,
                                                                gpointer iface_data)
{
	gitg_commit_action_checkout_gitg_ext_ui_element_parent_iface = g_type_interface_peek_parent (iface);
	iface->activate = (void (*) (GitgExtUIElement*)) gitg_commit_action_checkout_real_activate;
	iface->get_application = gitg_commit_action_checkout_real_get_application;
	iface->set_application = gitg_commit_action_checkout_real_set_application;
	iface->get_id = (gchar* (*) (GitgExtUIElement*)) gitg_commit_action_checkout_get_id;
	iface->get_display_name = gitg_commit_action_checkout_real_get_display_name;
	iface->get_description = (gchar* (*) (GitgExtUIElement*)) gitg_commit_action_checkout_get_description;
}

static void
gitg_commit_action_checkout_gitg_ext_action_interface_init (GitgExtActionIface * iface,
                                                            gpointer iface_data)
{
	gitg_commit_action_checkout_gitg_ext_action_parent_iface = g_type_interface_peek_parent (iface);
}

static void
gitg_commit_action_checkout_gitg_ext_commit_action_interface_init (GitgExtCommitActionIface * iface,
                                                                   gpointer iface_data)
{
	gitg_commit_action_checkout_gitg_ext_commit_action_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_action_interface = gitg_commit_action_checkout_real_get_action_interface;
	iface->set_action_interface = gitg_commit_action_checkout_real_set_action_interface;
	iface->get_commit = gitg_commit_action_checkout_real_get_commit;
	iface->set_commit = gitg_commit_action_checkout_real_set_commit;
}

static void
gitg_commit_action_checkout_instance_init (GitgCommitActionCheckout * self,
                                           gpointer klass)
{
	self->priv = gitg_commit_action_checkout_get_instance_private (self);
}

static void
gitg_commit_action_checkout_finalize (GObject * obj)
{
	GitgCommitActionCheckout * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_COMMIT_ACTION_CHECKOUT, GitgCommitActionCheckout);
	_g_object_unref0 (self->priv->_application);
	_g_object_unref0 (self->priv->_action_interface);
	_g_object_unref0 (self->priv->_commit);
	G_OBJECT_CLASS (gitg_commit_action_checkout_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_commit_action_checkout_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgCommitActionCheckoutClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_commit_action_checkout_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgCommitActionCheckout), 0, (GInstanceInitFunc) gitg_commit_action_checkout_instance_init, NULL };
	static const GInterfaceInfo gitg_ext_ui_element_info = { (GInterfaceInitFunc) gitg_commit_action_checkout_gitg_ext_ui_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_ext_action_info = { (GInterfaceInitFunc) gitg_commit_action_checkout_gitg_ext_action_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_ext_commit_action_info = { (GInterfaceInitFunc) gitg_commit_action_checkout_gitg_ext_commit_action_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_commit_action_checkout_type_id;
	gitg_commit_action_checkout_type_id = g_type_register_static (G_TYPE_OBJECT, "GitgCommitActionCheckout", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_commit_action_checkout_type_id, GITG_EXT_TYPE_UI_ELEMENT, &gitg_ext_ui_element_info);
	g_type_add_interface_static (gitg_commit_action_checkout_type_id, GITG_EXT_TYPE_ACTION, &gitg_ext_action_info);
	g_type_add_interface_static (gitg_commit_action_checkout_type_id, GITG_EXT_TYPE_COMMIT_ACTION, &gitg_ext_commit_action_info);
	GitgCommitActionCheckout_private_offset = g_type_add_instance_private (gitg_commit_action_checkout_type_id, sizeof (GitgCommitActionCheckoutPrivate));
	return gitg_commit_action_checkout_type_id;
}

GType
gitg_commit_action_checkout_get_type (void)
{
	static gsize gitg_commit_action_checkout_type_id__once = 0;
	if (g_once_init_enter (&gitg_commit_action_checkout_type_id__once)) {
		GType gitg_commit_action_checkout_type_id;
		gitg_commit_action_checkout_type_id = gitg_commit_action_checkout_get_type_once ();
		g_once_init_leave (&gitg_commit_action_checkout_type_id__once, gitg_commit_action_checkout_type_id);
	}
	return gitg_commit_action_checkout_type_id__once;
}

static void
_vala_gitg_commit_action_checkout_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec)
{
	GitgCommitActionCheckout * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_COMMIT_ACTION_CHECKOUT, GitgCommitActionCheckout);
	switch (property_id) {
		case GITG_COMMIT_ACTION_CHECKOUT_APPLICATION_PROPERTY:
		g_value_take_object (value, gitg_ext_ui_element_get_application ((GitgExtUIElement*) self));
		break;
		case GITG_COMMIT_ACTION_CHECKOUT_ACTION_INTERFACE_PROPERTY:
		g_value_set_object (value, gitg_ext_commit_action_get_action_interface ((GitgExtCommitAction*) self));
		break;
		case GITG_COMMIT_ACTION_CHECKOUT_COMMIT_PROPERTY:
		g_value_set_object (value, gitg_ext_commit_action_get_commit ((GitgExtCommitAction*) self));
		break;
		case GITG_COMMIT_ACTION_CHECKOUT_ID_PROPERTY:
		g_value_take_string (value, gitg_commit_action_checkout_get_id (self));
		break;
		case GITG_COMMIT_ACTION_CHECKOUT_DISPLAY_NAME_PROPERTY:
		g_value_take_string (value, gitg_ext_ui_element_get_display_name ((GitgExtUIElement*) self));
		break;
		case GITG_COMMIT_ACTION_CHECKOUT_DESCRIPTION_PROPERTY:
		g_value_take_string (value, gitg_commit_action_checkout_get_description (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gitg_commit_action_checkout_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec)
{
	GitgCommitActionCheckout * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_COMMIT_ACTION_CHECKOUT, GitgCommitActionCheckout);
	switch (property_id) {
		case GITG_COMMIT_ACTION_CHECKOUT_APPLICATION_PROPERTY:
		gitg_ext_ui_element_set_application ((GitgExtUIElement*) self, g_value_get_object (value));
		break;
		case GITG_COMMIT_ACTION_CHECKOUT_ACTION_INTERFACE_PROPERTY:
		gitg_ext_commit_action_set_action_interface ((GitgExtCommitAction*) self, g_value_get_object (value));
		break;
		case GITG_COMMIT_ACTION_CHECKOUT_COMMIT_PROPERTY:
		gitg_ext_commit_action_set_commit ((GitgExtCommitAction*) self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

