/* gitg-ext-searchable.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-ext-searchable.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2014 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include "libgitg-ext.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

static void gitg_ext_searchable_real_search_move (GitgExtSearchable* self,
                                           const gchar* key,
                                           gboolean up);
static gboolean gitg_ext_searchable_real_show_buttons (GitgExtSearchable* self);
static GType gitg_ext_searchable_get_type_once (void);

static void
gitg_ext_searchable_real_search_move (GitgExtSearchable* self,
                                      const gchar* key,
                                      gboolean up)
{
	g_return_if_fail (key != NULL);
}

void
gitg_ext_searchable_search_move (GitgExtSearchable* self,
                                 const gchar* key,
                                 gboolean up)
{
	GitgExtSearchableIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = GITG_EXT_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->search_move) {
		_iface_->search_move (self, key, up);
	}
}

static gboolean
gitg_ext_searchable_real_show_buttons (GitgExtSearchable* self)
{
	gboolean result;
	result = FALSE;
	return result;
}

gboolean
gitg_ext_searchable_show_buttons (GitgExtSearchable* self)
{
	GitgExtSearchableIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = GITG_EXT_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->show_buttons) {
		return _iface_->show_buttons (self);
	}
	return FALSE;
}

gchar*
gitg_ext_searchable_get_search_text (GitgExtSearchable* self)
{
	GitgExtSearchableIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = GITG_EXT_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->get_search_text) {
		return _iface_->get_search_text (self);
	}
	return NULL;
}

void
gitg_ext_searchable_set_search_text (GitgExtSearchable* self,
                                     const gchar* value)
{
	GitgExtSearchableIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = GITG_EXT_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->set_search_text) {
		_iface_->set_search_text (self, value);
	}
}

gboolean
gitg_ext_searchable_get_search_visible (GitgExtSearchable* self)
{
	GitgExtSearchableIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = GITG_EXT_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->get_search_visible) {
		return _iface_->get_search_visible (self);
	}
	return FALSE;
}

void
gitg_ext_searchable_set_search_visible (GitgExtSearchable* self,
                                        gboolean value)
{
	GitgExtSearchableIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = GITG_EXT_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->set_search_visible) {
		_iface_->set_search_visible (self, value);
	}
}

gboolean
gitg_ext_searchable_get_search_available (GitgExtSearchable* self)
{
	GitgExtSearchableIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = GITG_EXT_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->get_search_available) {
		return _iface_->get_search_available (self);
	}
	return FALSE;
}

void
gitg_ext_searchable_set_search_entry (GitgExtSearchable* self,
                                      GtkEntry* value)
{
	GitgExtSearchableIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = GITG_EXT_SEARCHABLE_GET_INTERFACE (self);
	if (_iface_->set_search_entry) {
		_iface_->set_search_entry (self, value);
	}
}

static void
gitg_ext_searchable_default_init (GitgExtSearchableIface * iface,
                                  gpointer iface_data)
{
	g_object_interface_install_property (iface, g_param_spec_string ("search-text", "search-text", "search-text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_interface_install_property (iface, g_param_spec_boolean ("search-visible", "search-visible", "search-visible", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_interface_install_property (iface, g_param_spec_boolean ("search-available", "search-available", "search-available", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_interface_install_property (iface, g_param_spec_object ("search-entry", "search-entry", "search-entry", gtk_entry_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	iface->search_move = gitg_ext_searchable_real_search_move;
	iface->show_buttons = gitg_ext_searchable_real_show_buttons;
}

/**
 * gitg Searchable interface.
 *
 * The Searchable interface can be implemented when an activity supports a
 * searching.
 */
 G_GNUC_NO_INLINE static GType
gitg_ext_searchable_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgExtSearchableIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_ext_searchable_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType gitg_ext_searchable_type_id;
	gitg_ext_searchable_type_id = g_type_register_static (G_TYPE_INTERFACE, "GitgExtSearchable", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (gitg_ext_searchable_type_id, G_TYPE_OBJECT);
	g_type_interface_add_prerequisite (gitg_ext_searchable_type_id, GITG_EXT_TYPE_ACTIVITY);
	return gitg_ext_searchable_type_id;
}

GType
gitg_ext_searchable_get_type (void)
{
	static gsize gitg_ext_searchable_type_id__once = 0;
	if (g_once_init_enter (&gitg_ext_searchable_type_id__once)) {
		GType gitg_ext_searchable_type_id;
		gitg_ext_searchable_type_id = gitg_ext_searchable_get_type_once ();
		g_once_init_leave (&gitg_ext_searchable_type_id__once, gitg_ext_searchable_type_id);
	}
	return gitg_ext_searchable_type_id__once;
}

